@@ -29,9 +29,9 @@ from __future__ import absolute_import
 from __future__ import print_function
 from __future__ import unicode_literals
 
-__version__ = "0.4"
+__version__ = "0.5"
 
-from xsge import gui, physics
+from xsge import gui, path, physics, tmx
 
 
-__all__ = ["gui", "physics"]
+__all__ = ["gui", "path", "physics", "tmx"]
